@@ -26,7 +26,7 @@ AUXILIARY FUCTIONS FOR THE ESTIMATION OF THE VAR-TYPE MODEL: FOR USE ON THE SEAS
 ---------------------------------------------------------------------------------------------------------------------------------------------------------- */
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-inline arma::mat armaP_ridge_diag(const arma::vec & S, const arma::vec & target, const double lambda){
+inline arma::mat armaP_ridge_diag(const arma::vec& S, const arma::vec& target, const double lambda){
 	/* ---------------------------------------------------------------------------
 	The ridge estimator in C++. Wrapper for the subroutines
 	- S      > The sample covariance matrix (a numeric matrix on the R side)
@@ -70,6 +70,7 @@ inline Rcpp::List armaEigenDecomp_blockDiagOnly(const arma::mat symMat, const ar
 	return Rcpp::List::create(Rcpp::Named("values") = eigvals, Rcpp::Named("vectors") = eigvecs);
 }
 
+/*
 inline arma::cube armaArray2cube(Rcpp::NumericVector Yraw){
 	/////////////////////////////////////////////////////////////////////////////////////////
 	// reformatting of data to an arma::cube format
@@ -80,8 +81,9 @@ inline arma::cube armaArray2cube(Rcpp::NumericVector Yraw){
 	arma::cube Y(vecArray.begin(), arrayDims[0], arrayDims[1], arrayDims[2], false);
 	return Y;
 }
+*/
 
-inline arma::mat armaVARzerosCorrection_dense(arma::mat Ahat, int pRows, int pCols, const arma::mat eigvecP, const arma::vec eigvalP, const arma::mat eigvecVAR, const arma::vec eigvalVAR, const double lambda, const arma::uvec zerosR, const arma::uvec zerosC){
+inline arma::mat armaVARzerosCorrection_dense(arma::mat Ahat, int pRows, int pCols, const arma::mat& eigvecP, const arma::vec eigvalP, const arma::mat& eigvecVAR, const arma::vec eigvalVAR, const double lambda, const arma::uvec zerosR, const arma::uvec zerosC){
 	/////////////////////////////////////////////////////////////////////////////////////////
 	// evaluates and applies the imposed zero constraint correction, assuming few zeros
 	/////////////////////////////////////////////////////////////////////////////////////////
@@ -106,7 +108,7 @@ inline arma::mat armaVARzerosCorrection_dense(arma::mat Ahat, int pRows, int pCo
 	return Ahat - reshape(Vu * Q * Ahat.elem(zerosID), pRows, pCols);
 }
 
-inline arma::mat armaVARzerosCorrection_sparse(arma::mat Ahat, int pRows, int pCols, const arma::mat P, const arma::mat eigvecVAR, const arma::vec eigvalVAR, const double lambda, const arma::uvec zerosR, const arma::uvec zerosC){
+inline arma::mat armaVARzerosCorrection_sparse(arma::mat Ahat, int pRows, int pCols, const arma::mat& P, const arma::mat& eigvecVAR, const arma::vec eigvalVAR, const double lambda, const arma::uvec zerosR, const arma::uvec zerosC){
 	/////////////////////////////////////////////////////////////////////////////////////////
 	// evaluates and applies the imposed zero constraint correction, assuming many zeros
 	/////////////////////////////////////////////////////////////////////////////////////////
@@ -140,16 +142,19 @@ AUXILIARY FUCTIONS FOR THE ESTIMATION OF THE VAR(1) MODEL: FOR USE ON THE SEASID
 ---------------------------------------------------------------------------------------------------------------------------------------------------------- */
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-inline arma::cube armaVAR_array2cube_withMissing(Rcpp::NumericVector Yraw, const arma::uvec unbalancedR, const arma::uvec unbalancedC){
+inline arma::cube armaVAR_array2cube_withMissing(Rcpp::NumericVector& Yraw, const arma::uvec unbalancedR, const arma::uvec unbalancedC){
 	/////////////////////////////////////////////////////////////////////////////////////////
 	// set profiles of missing (time, sample)-points to missing
 	/////////////////////////////////////////////////////////////////////////////////////////
 
 	// reformatting of data to an arma::cube format
-	const Rcpp::NumericVector vecArray(Yraw);
-	Rcpp::NumericVector vecArraySlh = Rcpp::clone(vecArray);
-	Rcpp::IntegerVector arrayDims = vecArraySlh.attr("dim");
-  	arma::cube Y(vecArraySlh.begin(), arrayDims[0], arrayDims[1], arrayDims[2], false);
+	// const Rcpp::NumericVector vecArray(Yraw);
+	// Rcpp::NumericVector vecArraySlh = Rcpp::clone(vecArray);
+	// Rcpp::IntegerVector arrayDims = vecArraySlh.attr("dim");
+  	// arma::cube Y(vecArraySlh.begin(), arrayDims[0], arrayDims[1], arrayDims[2], false);
+
+	Rcpp::IntegerVector arrayDims = Yraw.attr("dim");
+  	arma::cube Y(Yraw.begin(), arrayDims[0], arrayDims[1], arrayDims[2]);
 
 	// insert missings per slice 
 	int nMissing = unbalancedR.n_elem;
@@ -163,20 +168,24 @@ inline arma::cube armaVAR_array2cube_withMissing(Rcpp::NumericVector Yraw, const
 	return Y;
 }
 
-inline arma::cube armaVAR_array2cube_withoutMissing(Rcpp::NumericVector Yraw){
+inline arma::cube armaVAR_array2cube_withoutMissing(Rcpp::NumericVector& Yraw){
 	/////////////////////////////////////////////////////////////////////////////////////////
 	// set profiles of missing (time, sample)-points to missing
 	/////////////////////////////////////////////////////////////////////////////////////////
 
 	// reformatting of data to an arma::cube format
-	const Rcpp::NumericVector vecArray(Yraw);
-	Rcpp::NumericVector vecArraySlh = Rcpp::clone(vecArray);
-	Rcpp::IntegerVector arrayDims = vecArraySlh.attr("dim");
-	arma::cube Y(vecArraySlh.begin(), arrayDims[0], arrayDims[1], arrayDims[2], false);
+	// const Rcpp::NumericVector vecArray(Yraw);
+	// Rcpp::NumericVector vecArraySlh = Rcpp::clone(vecArray);
+	// Rcpp::IntegerVector arrayDims = vecArraySlh.attr("dim");
+	// arma::cube Y(vecArraySlh.begin(), arrayDims[0], arrayDims[1], arrayDims[2], false);
+
+	Rcpp::IntegerVector arrayDims = Yraw.attr("dim");
+  	arma::cube Y(Yraw.begin(), arrayDims[0], arrayDims[1], arrayDims[2]);
+
 	return Y;
 }
 
-inline arma::mat armaVAR1_Shat_ML(arma::cube Y, const arma::mat A){
+inline arma::mat armaVAR1_Shat_ML(const arma::cube& Y, const arma::mat& A){
 	/////////////////////////////////////////////////////////////////////////////////////////
 	// Least squares estimation of the regression parameter A of a VAR(1) model
 	/////////////////////////////////////////////////////////////////////////////////////////
@@ -198,7 +207,7 @@ inline arma::mat armaVAR1_Shat_ML(arma::cube Y, const arma::mat A){
 	return S / dof;
 }
 
-inline const double armaVAR1_loglik(arma::cube Y, arma::mat A, arma::mat P){
+inline double armaVAR1_loglik(const arma::cube& Y, arma::mat& A, arma::mat& P){
 	/////////////////////////////////////////////////////////////////////////////////////////
 	// Evaluate the log-likelihood of the VAR1 model
 	/////////////////////////////////////////////////////////////////////////////////////////
@@ -217,7 +226,7 @@ inline const double armaVAR1_loglik(arma::cube Y, arma::mat A, arma::mat P){
 
 		// limit residuals to those time points without missing
 		arma::mat colsums = arma::sum(Yi);
-		arma::uvec idT = find_finite(colsums);
+		arma::uvec idT = arma::find_finite(colsums);
 		Yi = Yi.cols(idT);
 
 		// update log-likelihood and d.o.f.
@@ -231,7 +240,7 @@ inline const double armaVAR1_loglik(arma::cube Y, arma::mat A, arma::mat P){
 	return - dofs * p * log(2 * arma::datum::pi) / 2 + dofs * logDetP /2 + LL;
 }
 
-inline arma::mat armaVAR1_COVYhat(arma::cube Y){
+inline arma::mat armaVAR1_COVYhat(const arma::cube& Y){
 	/////////////////////////////////////////////////////////////////////////////////////////
 	// Covariance estimation of the multivariate time series data.
 	/////////////////////////////////////////////////////////////////////////////////////////
@@ -257,22 +266,22 @@ inline arma::mat armaVAR1_COVYhat(arma::cube Y){
 	return COVY / COVYdof;
 }
 
-inline arma::mat armaVAR1_VARYhat(arma::cube Y, bool & efficient, arma::mat & unbalanced ){
+inline arma::mat armaVAR1_VARYhat(const arma::cube& Y, bool efficient, arma::mat unbalanced){
 	/////////////////////////////////////////////////////////////////////////////////////////
 	// Variance estimation of the multivariate time series data.
 	/////////////////////////////////////////////////////////////////////////////////////////
  
 	// variance estimation plus d.o.f. calculation
-	int VARYdof = 0; int p = Y.n_rows; int T = Y.n_cols; int n = Y.n_slices; arma::uvec idKeep;	
-	if (efficient){		
-		idKeep = arma::find(unbalanced.col(0) != T);	
-		if (idKeep.n_rows > 0){            	
+	int VARYdof = 0; int p = Y.n_rows; int T = Y.n_cols; int n = Y.n_slices; arma::uvec idKeep;	// arma::mat unbalancedVAR=unbalanced;
+	if (efficient && unbalanced.n_rows > 0){	
+		idKeep = arma::find(unbalanced.col(0) != T);
+    		if (idKeep.n_rows > 0){            	
 			unbalanced = unbalanced.rows(idKeep);
 		}
 	}
 	int nMissing = unbalanced.n_rows;    
 	arma::mat VARY = arma::mat(p, p, arma::fill::zeros);
-	arma::mat Yk;
+	arma::mat Yk;	
 	for (int k = 0; k < n; ++k) {
 		Yk = Y.slice(k);
 		Yk.elem( arma::find_nonfinite(Yk) ).zeros();
@@ -287,7 +296,7 @@ inline arma::mat armaVAR1_VARYhat(arma::cube Y, bool & efficient, arma::mat & un
 	return VARY / VARYdof;
 }
 
-inline arma::mat armaVAR1_Ahat_ridgeML(arma::mat P, arma::mat COVY, const arma::mat eigvecVARY, const arma::vec eigvalVARY, const double & lambdaA, arma::mat targetA){
+inline arma::mat armaVAR1_Ahat_ridgeML(arma::mat& P, arma::mat& COVY, const arma::mat& eigvecVARY, const arma::vec eigvalVARY, const double lambdaA, arma::mat& targetA){
 	/////////////////////////////////////////////////////////////////////////////////////////
 	// Ridge ML estimate the regression coefficient matrix A of a VAR model
 	/////////////////////////////////////////////////////////////////////////////////////////
@@ -301,7 +310,7 @@ inline arma::mat armaVAR1_Ahat_ridgeML(arma::mat P, arma::mat COVY, const arma::
 	return eigvecP * ((arma::trans(eigvecP) * (targetA + P * COVY) * eigvecVARY) / (eigvalP * arma::trans(eigvalVARY) + lambdaA)) * arma::trans(eigvecVARY);
 }
 
-inline arma::mat armaVAR1_Ahat_ridgeML_speed(arma::mat P, arma::mat COVY, const arma::mat eigvecVARY, const arma::vec eigvalVARY, const double & lambdaA, arma::mat targetA){
+inline arma::mat armaVAR1_Ahat_ridgeML_speed(arma::mat& P, arma::mat& COVY, const arma::mat& eigvecVARY, const arma::vec eigvalVARY, const double lambdaA, arma::mat& targetA){
 	/////////////////////////////////////////////////////////////////////////////////////////
 	// Ridge ML estimate the regression coefficient matrix A of a VAR model
 	/////////////////////////////////////////////////////////////////////////////////////////
@@ -315,7 +324,7 @@ inline arma::mat armaVAR1_Ahat_ridgeML_speed(arma::mat P, arma::mat COVY, const
 	return eigvecP * ((arma::trans(eigvecP) * (targetA + P * COVY)) / (eigvalP * arma::trans(eigvalVARY) + lambdaA)) * arma::trans(eigvecVARY);
 }
 
-inline arma::mat armaVAR1_Ahat_ridgeSS(arma::mat VARY, const arma::mat & COVY, const double lambdaA, arma::mat & targetA){
+inline arma::mat armaVAR1_Ahat_ridgeSS(arma::mat VARY, const arma::mat& COVY, const double lambdaA, arma::mat& targetA){
 	/////////////////////////////////////////////////////////////////////////////////////////
 	// Least squares estimation of the regression parameter A of a VAR(1) model
 	/////////////////////////////////////////////////////////////////////////////////////////
@@ -325,7 +334,7 @@ inline arma::mat armaVAR1_Ahat_ridgeSS(arma::mat VARY, const arma::mat & COVY, c
 	return (targetA + COVY) * arma::inv_sympd(VARY);
 }
 
-inline const double armaVAR1_convergenceEvaluation(arma::mat Ahat, arma::mat Aprev, arma::mat Phat, arma::mat Pprev){
+inline double armaVAR1_convergenceEvaluation(arma::mat& Ahat, arma::mat& Aprev, arma::mat& Phat, arma::mat& Pprev){
 	/////////////////////////////////////////////////////////////////////////////////////////
 	// assess maximum difference between the current and previous estimates
 	/////////////////////////////////////////////////////////////////////////////////////////
@@ -335,7 +344,7 @@ inline const double armaVAR1_convergenceEvaluation(arma::mat Ahat, arma::mat Apr
 	return maxis.max();
 }
 
-inline arma::mat armaVAR1_Ahat_zeros(const arma::mat & P, arma::mat & COVY, const arma::mat & eigvecVARY, const arma::vec & eigvalVARY, const double & lambdaA, const arma::mat & targetA, std::string fitA, const arma::uvec & zerosR, const arma::uvec & zerosC, std::string & zerosAfit){
+inline arma::mat armaVAR1_Ahat_zeros(const arma::mat& P, arma::mat& COVY, const arma::mat& eigvecVARY, const arma::vec eigvalVARY, const double lambdaA, const arma::mat& targetA, std::string fitA, const arma::uvec zerosR, const arma::uvec zerosC, std::string zerosAfit){
 	/////////////////////////////////////////////////////////////////////////////////////////
 	// Ridge ML estimate the regression coefficient matrix A of a VAR model with known support
 	/////////////////////////////////////////////////////////////////////////////////////////
@@ -378,8 +387,8 @@ WRAPPERS FUNCTIONs FOR THE VAR(1) MODEL ESTIMATION
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
 // [[Rcpp::export(".armaVAR1_ridgeML")]]
-Rcpp::List armaVAR1_ridgeML(Rcpp::NumericVector & Yraw, const double & lambdaA, const double lambdaP, arma::mat & targetA, arma::mat & targetP, std::string targetPtype, 
-std::string fitA, arma::mat & unbalanced, bool & diagP, bool & efficient, const int & nInit, const double & minSuccDiff){
+Rcpp::List armaVAR1_ridgeML(Rcpp::NumericVector& Yraw, const double lambdaA, const double lambdaP, arma::mat& targetA, arma::mat& targetP, std::string targetPtype, 
+std::string fitA, arma::mat& unbalanced, bool diagP, bool efficient, const int nInit, const double minSuccDiff){
 
 	// set profiles of missing (time, sample)-points to missing
 	arma::cube Y;
@@ -418,7 +427,7 @@ std::string fitA, arma::mat & unbalanced, bool & diagP, bool & efficient, const
 		// declare storage variables
 		arma::mat Aprev; arma::mat Pprev;
         
-        // for speed a multiplication is taken outside the for-loop 
+        	// for speed a multiplication is taken outside the for-loop 
 		COVY = COVY * eigvecsVARY;
 		targetA = targetA * eigvecsVARY;
     
@@ -457,8 +466,8 @@ std::string fitA, arma::mat & unbalanced, bool & diagP, bool & efficient, const
 }
 
 // [[Rcpp::export(".armaVAR1_ridgeML_zerosA")]]
-Rcpp::List armaVAR1_ridgeML_zerosA(Rcpp::NumericVector Yraw, const double lambdaA, const double lambdaP, arma::mat targetA, arma::mat targetP, std::string targetPtype, 
-std::string fitA, arma::mat unbalanced, bool diagP, bool efficient, const int nInit, const double minSuccDiff, const arma::uvec zerosR, const arma::uvec zerosC, std::string zerosAfit){
+Rcpp::List armaVAR1_ridgeML_zerosA(Rcpp::NumericVector& Yraw, const double lambdaA, const double lambdaP, arma::mat& targetA, arma::mat& targetP, std::string targetPtype, 
+std::string fitA, arma::mat unbalanced, bool diagP, bool efficient, const int nInit, const double minSuccDiff, const arma::uvec& zerosR, const arma::uvec& zerosC, std::string zerosAfit){
 
 	// set profiles of missing (time, sample)-points to missing
 	arma::cube Y;
@@ -543,31 +552,31 @@ Rcpp::List armaEigenDecomp_blockDiagOnly_forR(const arma::mat symMat, const arma
 }
 
 // [[Rcpp::export(".armaVAR1_Shat_ML")]]
-arma::mat armaVAR1_Shat_ML_forR(Rcpp::NumericVector Yraw, const arma::mat A){
+arma::mat armaVAR1_Shat_ML_forR(Rcpp::NumericVector& Yraw, const arma::mat& A){
 	// Least squares estimation of the regression parameter A of a VAR(1) model
 	// First reformatting of data to an arma::cube format
-	arma::cube Y = armaArray2cube(Yraw); 
+	arma::cube Y = armaVAR_array2cube_withoutMissing(Yraw); 
 	return armaVAR1_Shat_ML(Y, A);
 }
 
 // [[Rcpp::export(".armaVAR1_COVYhat")]]
-arma::mat armaVAR1_COVYhat_forR(Rcpp::NumericVector Yraw){
+arma::mat armaVAR1_COVYhat_forR(Rcpp::NumericVector& Yraw){
 	// Covariance estimation of the multivariate time series data.
 	// First reformatting of data to an arma::cube format
-	arma::cube Y = armaArray2cube(Yraw); 
+	arma::cube Y = armaVAR_array2cube_withoutMissing(Yraw); 
 	return armaVAR1_COVYhat(Y);
 }
 
 // [[Rcpp::export(".armaVAR1_VARYhat")]]
-arma::mat armaVAR1_VARYhat_forR(Rcpp::NumericVector Yraw, bool efficient, arma::mat unbalanced){
+arma::mat armaVAR1_VARYhat_forR(Rcpp::NumericVector& Yraw, bool efficient, arma::mat unbalanced){
 	// Variance estimation of the multivariate time series data.
 	// First reformatting of data to an arma::cube format
-	arma::cube Y = armaArray2cube(Yraw); 
+	arma::cube Y = armaVAR_array2cube_withoutMissing(Yraw); 
 	return armaVAR1_VARYhat(Y, efficient, unbalanced);
 }
 
 // [[Rcpp::export(".armaVAR1_Ahat_zeros")]]
-arma::mat armaVAR1_Ahat_zeros_forR(const arma::mat & P, arma::mat & COVY, const arma::mat & eigvecVARY, const arma::vec & eigvalVARY, const double & lambdaA, const arma::mat & targetA, std::string fitA, const arma::uvec & zerosR, const arma::uvec & zerosC, std::string & zerosAfit){
+arma::mat armaVAR1_Ahat_zeros_forR(const arma::mat& P, arma::mat& COVY, const arma::mat& eigvecVARY, const arma::vec eigvalVARY, const double lambdaA, const arma::mat& targetA, std::string fitA, const arma::uvec& zerosR, const arma::uvec& zerosC, std::string zerosAfit){
 	// see armaVAR1_Ahat_zeros
 	return armaVAR1_Ahat_zeros(P, COVY, eigvecVARY, eigvalVARY, lambdaA, targetA, fitA, zerosR, zerosC, zerosAfit);
 }
@@ -579,16 +588,16 @@ arma::mat armaP_defaultTarget_forR(arma::mat S, std::string targetType, const do
 }
 
 // [[Rcpp::export(".armaVAR_array2cube_withMissing")]]
-arma::cube armaVAR_array2cube_withMissing_forR(Rcpp::NumericVector & Yraw, const arma::uvec & unbalancedR, const arma::uvec & unbalancedC){
+arma::cube armaVAR_array2cube_withMissing_forR(Rcpp::NumericVector& Yraw, const arma::uvec unbalancedR, const arma::uvec unbalancedC){
 	// set profiles of missing (time, sample)-points to missing
 	// First reformatting of data to an arma::cube format
 	return armaVAR_array2cube_withMissing(Yraw, unbalancedR, unbalancedC);
 }
 
 // [[Rcpp::export(".armaVAR_array2cube_withoutMissing")]]
-arma::cube armaVAR_array2cube_withoutMissing_forR(Rcpp::NumericVector & Yraw){
+arma::cube armaVAR_array2cube_withoutMissing_forR(Rcpp::NumericVector& Yraw){
 	// reformatting of data to an arma::cube format
-	return armaVAR_array2cube_withoutMissing_forR(Yraw);
+	return armaVAR_array2cube_withoutMissing(Yraw);
 }
 
 // [[Rcpp::export(".armaEigenDecomp")]]
@@ -600,24 +609,24 @@ Rcpp::List armaEigenDecomp_forR(const arma::mat symMat){
 }
 
 // [[Rcpp::export(".armaVAR1_convergenceEvaluation")]]
-const double armaVAR1_convergenceEvaluation_forR(arma::mat Ahat, arma::mat Aprev, arma::mat Phat, arma::mat Pprev){
+double armaVAR1_convergenceEvaluation_forR(arma::mat& Ahat, arma::mat& Aprev, arma::mat& Phat, arma::mat& Pprev){
 	// assess maximum difference between the current and previous estimates
 	return armaVAR1_convergenceEvaluation(Ahat, Aprev, Phat, Pprev);
 }
 
 // [[Rcpp::export(".armaVAR1_Ahat_ridgeML")]]
-arma::mat armaVAR1_Ahat_ridgeML_forR(arma::mat P, arma::mat COVY, const arma::mat eigvecVARY, const arma::colvec eigvalVARY, const double lambdaA, arma::mat targetA){
+arma::mat armaVAR1_Ahat_ridgeML_forR(arma::mat& P, arma::mat& COVY, const arma::mat& eigvecVARY, const arma::colvec eigvalVARY, const double lambdaA, arma::mat& targetA){
 	return armaVAR1_Ahat_ridgeML(P, COVY, eigvecVARY, eigvalVARY, lambdaA, targetA);
 }
 
 // [[Rcpp::export(".armaVAR1_Ahat_ridgeSS")]]
-arma::mat armaVAR1_Ahat_ridgeSS_forR(arma::mat VARY, arma::mat COVY, const double & lambdaA, arma::mat & targetA){
+arma::mat armaVAR1_Ahat_ridgeSS_forR(arma::mat& VARY, arma::mat& COVY, const double & lambdaA, arma::mat& targetA){
 	// see armaVARX1_Ahat_ridgeSS
 	return armaVAR1_Ahat_ridgeSS(VARY, COVY, lambdaA, targetA);
 }
 
 // [[Rcpp::export(".armaVAR1_loglik_LOOCVinternal")]]
-const double armaVAR1_loglikLOOCVinternal_forR(arma::vec Yt1, arma::vec Yt0, arma::mat A, arma::mat P){
+double armaVAR1_loglikLOOCVinternal_forR(arma::vec Yt1, arma::vec Yt0, arma::mat& A, arma::mat& P){
 
 	double logDetP; double detPsign;
 	arma::log_det(logDetP, detPsign, P);
@@ -627,10 +636,11 @@ const double armaVAR1_loglikLOOCVinternal_forR(arma::vec Yt1, arma::vec Yt0, arm
 }
 
 // [[Rcpp::export(".armaVAR1_loglik")]]
-const double armaVAR1_loglik_forR(Rcpp::NumericVector Yraw, arma::mat A, arma::mat P){
+double armaVAR1_loglik_forR(Rcpp::NumericVector& Yraw, arma::mat& A, arma::mat& P){
 	// Evaluate the log-likelihood of the VAR1 model
 	// First reformatting of data to an arma::cube format
-	arma::cube Y = armaArray2cube(Yraw);
+	arma::cube Y = armaVAR_array2cube_withoutMissing(Yraw);
 	return armaVAR1_loglik(Y, A, P);
 }
 
+
